package com.rwk.web.controller.ability;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.rwk.common.annotation.Log;
import com.rwk.common.enums.BusinessType;
import com.rwk.system.domain.RwkStaffInformation;
import com.rwk.system.service.IRwkStaffInformationService;
import com.rwk.common.core.controller.BaseController;
import com.rwk.common.core.domain.AjaxResult;
import com.rwk.common.utils.poi.ExcelUtil;
import com.rwk.common.core.page.TableDataInfo;

/**
 * 人员信息Controller
 * 
 * @author rick
 * @date 2024-11-06
 */
@Controller
@RequestMapping("/system/information")
public class RwkStaffInformationController extends BaseController
{
    private String prefix = "system/information";

    @Autowired
    private IRwkStaffInformationService rwkStaffInformationService;

    @RequiresPermissions("system:information:view")
    @GetMapping()
    public String information()
    {
        return prefix + "/information";
    }

    @GetMapping("/addressBook")
    public String addressBook()
    {
        return prefix + "/addressBook";
    }

    /**
     * 查询人员信息列表
     */
    @RequiresPermissions("system:information:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(RwkStaffInformation rwkStaffInformation)
    {
        startPage();
        List<RwkStaffInformation> list = rwkStaffInformationService.selectRwkStaffInformationList(rwkStaffInformation);
        return getDataTable(list);
    }

    /**
     * 导出人员信息列表
     */
    @RequiresPermissions("system:information:export")
    @Log(title = "人员信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(RwkStaffInformation rwkStaffInformation)
    {
        List<RwkStaffInformation> list = rwkStaffInformationService.selectRwkStaffInformationList(rwkStaffInformation);
        ExcelUtil<RwkStaffInformation> util = new ExcelUtil<RwkStaffInformation>(RwkStaffInformation.class);
        return util.exportExcel(list, "人员信息数据");
    }

    /**
     * 新增人员信息
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存人员信息
     */
    @RequiresPermissions("system:information:add")
    @Log(title = "人员信息", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(RwkStaffInformation rwkStaffInformation)
    {
        return toAjax(rwkStaffInformationService.insertRwkStaffInformation(rwkStaffInformation));
    }

    /**
     * 修改人员信息
     */
    @RequiresPermissions("system:information:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        RwkStaffInformation rwkStaffInformation = rwkStaffInformationService.selectRwkStaffInformationById(id);
        mmap.put("rwkStaffInformation", rwkStaffInformation);
        return prefix + "/edit";
    }

    /**
     * 修改保存人员信息
     */
    @RequiresPermissions("system:information:edit")
    @Log(title = "人员信息", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(RwkStaffInformation rwkStaffInformation)
    {
        return toAjax(rwkStaffInformationService.updateRwkStaffInformation(rwkStaffInformation));
    }

    /**
     * 删除人员信息
     */
    @RequiresPermissions("system:information:remove")
    @Log(title = "人员信息", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(rwkStaffInformationService.deleteRwkStaffInformationByIds(ids));
    }
}
