package com.rwk.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.rwk.system.mapper.RwkStaffInformationMapper;
import com.rwk.system.domain.RwkStaffInformation;
import com.rwk.system.service.IRwkStaffInformationService;
import com.rwk.common.core.text.Convert;

/**
 * 人员信息Service业务层处理
 * 
 * @author rick
 * @date 2024-11-06
 */
@Service
public class RwkStaffInformationServiceImpl implements IRwkStaffInformationService 
{
    @Autowired
    private RwkStaffInformationMapper rwkStaffInformationMapper;

    /**
     * 查询人员信息
     * 
     * @param id 人员信息主键
     * @return 人员信息
     */
    @Override
    public RwkStaffInformation selectRwkStaffInformationById(Long id)
    {
        return rwkStaffInformationMapper.selectRwkStaffInformationById(id);
    }

    /**
     * 查询人员信息列表
     * 
     * @param rwkStaffInformation 人员信息
     * @return 人员信息
     */
    @Override
    public List<RwkStaffInformation> selectRwkStaffInformationList(RwkStaffInformation rwkStaffInformation)
    {
        return rwkStaffInformationMapper.selectRwkStaffInformationList(rwkStaffInformation);
    }

    /**
     * 新增人员信息
     * 
     * @param rwkStaffInformation 人员信息
     * @return 结果
     */
    @Override
    public int insertRwkStaffInformation(RwkStaffInformation rwkStaffInformation)
    {
        return rwkStaffInformationMapper.insertRwkStaffInformation(rwkStaffInformation);
    }

    /**
     * 修改人员信息
     * 
     * @param rwkStaffInformation 人员信息
     * @return 结果
     */
    @Override
    public int updateRwkStaffInformation(RwkStaffInformation rwkStaffInformation)
    {
        return rwkStaffInformationMapper.updateRwkStaffInformation(rwkStaffInformation);
    }

    /**
     * 批量删除人员信息
     * 
     * @param ids 需要删除的人员信息主键
     * @return 结果
     */
    @Override
    public int deleteRwkStaffInformationByIds(String ids)
    {
        return rwkStaffInformationMapper.deleteRwkStaffInformationByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除人员信息信息
     * 
     * @param id 人员信息主键
     * @return 结果
     */
    @Override
    public int deleteRwkStaffInformationById(Long id)
    {
        return rwkStaffInformationMapper.deleteRwkStaffInformationById(id);
    }
}
